@@ -278,9 +278,9 @@ class FlexModel(_MasterModel):
                 min_lsp_metric = min([lsp.effective_metric(self) for lsp in lsp_list])
                 for lsp in lsp_list:
                     if lsp.effective_metric(self) == min_lsp_metric:
-                        demand.path.append(lsp)
+                        demand.path.append([lsp])
 
-            if demand.path == []:
+            if demand.path == []:  # There are no end to end LSPs for the demand
                 src = demand.source_node_object.name
                 dest = demand.dest_node_object.name
 
@@ -323,17 +323,15 @@ class FlexModel(_MasterModel):
           - if no, look at next node downstream with IGP shortcuts
         5.  Look for manually set RSVP LSP metrics that may alter the path calculations
 
-        :param paths: List of lists; each list contains egress Interfaces along the path from
-        source to destination (ordered from source to destination)
-        :param node_paths: List of lists; each list contains node names along the path from
-        source to destination (ordered from source to destination)
+        :param paths: List of lists; each list contains egress Interfaces along the path from source to destination (ordered from source to destination)  # noqa E501
+        :param node_paths: List of lists; each list contains node names along the path from source to destination (ordered from source to destination)
 
-        :return: List of lists; each list contains Interfaces and/or RSVP LSPs along each path
-        from source to destination
+        :return: List of lists; each list contains Interfaces and/or RSVP LSPs along each path from source to destination  # noqa E501
         """
 
         # Check node_paths for igp_shortcuts_enabled nodes
         # TODO - this can likely be optimized
+
         all_nodes_in_paths = []
         for node_path in node_paths:
             all_nodes_in_paths = all_nodes_in_paths + node_path
@@ -347,12 +345,32 @@ class FlexModel(_MasterModel):
             return paths
 
         # ## Find LSPs on shortcut_enabled_nodes that connect to downstream nodes in paths ## #
+        # Substitute IGP enabled LSPs for Interfaces in paths
 
-        # List that will hold the paths that contain LSPs
-        paths_with_lsps = []
+        paths_with_lsps = self._insert_lsp_shortcuts(node_paths, paths)
+
+        if len(paths_with_lsps) == 1:
+            return paths_with_lsps
+
+        # Inspect paths to determine if manually set LSP metrics affect path selection
+        finalized_paths = self._inspect_for_lsp_metrics(paths_with_lsps)
+
+        return finalized_paths
+
+    def _insert_lsp_shortcuts(self, node_paths, paths):
+        """
+        Given node_paths and paths, finds and inserts LSPs from shortcut-enabled nodes
+        along the path
+
+        :param paths: List of lists; each list contains egress Interfaces along the path from source to destination (ordered from source to destination)  # noqa E501
+        :param node_paths: List of lists; each list contains node names along the path from source to destination (ordered from source to destination)
+
+        :return:  List of lists; each list is a path with any possible LSP shortcuts inserted in place
+        of the any applicable Interfaces
+        """
 
         # Substitute IGP enabled LSPs for Interfaces in paths
-        for node_path, interface_path in zip(node_paths, paths):
+        for node_path in node_paths:
             # Find Nodes along the path that have igp_shortcuts_enabled and have
             # LSPs to downstream Nodes in the path
             path_lsps = []  # List of LSPs to substitute into path
@@ -401,21 +419,21 @@ class FlexModel(_MasterModel):
                             next_node_to_check.append(lsp_end_node)
                             break
 
-            # Now that path_lsps is known, substitute those into path
-            if len(path_lsps) > 0:
-                path = interface_path
-                path_with_lsps = self._insert_lsps_into_path(path_lsps, path)
-                for component_path in path_with_lsps:
-                    paths_with_lsps.append(component_path)
-            else:
-                # No LSPs on path;
-                paths_with_lsps.append(interface_path)
-
-        if len(paths_with_lsps) == 1:
-            return paths_with_lsps
-
-        # Inspect paths to determine if manually set LSP metrics affect path selection
-        finalized_paths = self._inspect_for_lsp_metrics(paths_with_lsps)
+        # Now that path_lsps is known, substitute those into path
+        finalized_paths = []
+        if len(path_lsps) > 0:
+            for interface_path in paths:
+                finalized_path = self._insert_lsps_into_path(path_lsps, interface_path)
+                if finalized_path != -1:
+                    for path in finalized_path:
+                        # finalized_path may be a list of lists, so add each component path
+                        if path not in finalized_paths:
+                            finalized_paths.append(path)
+                else:
+                    finalized_paths.append(interface_path)
+        else:
+            # No LSPs available for shortcuts
+            finalized_paths = paths
 
         return finalized_paths
 
@@ -725,6 +743,7 @@ class FlexModel(_MasterModel):
         the parallel LSPs from a common source to a common destination
 
         Example::
+
             [[RSVP_LSP(source = B, dest = D, lsp_name = 'lsp_b_d_2'),
             RSVP_LSP(source = B, dest = D, lsp_name = 'lsp_b_d_1')],
             [RSVP_LSP(source = D, dest = F, lsp_name = 'lsp_d_f_1')]]
@@ -748,10 +767,19 @@ class FlexModel(_MasterModel):
             # [(start_index, end_index, parallel_lsp_1),. .
             # . . ((start_index, end_index, parallel_lsp_x)]
             lsp_group_slices = []
-            start_interface = [interface for interface in path if isinstance(interface, Interface) and
-                               interface.node_object == lsp_group[0].source_node_object][0]
-            end_interface = [interface for interface in path if isinstance(interface, Interface) and
-                             interface.remote_node_object == lsp_group[0].dest_node_object][0]
+
+            try:
+                start_interface = [interface for interface in path if isinstance(interface, Interface) and
+                                   interface.node_object == lsp_group[0].source_node_object][0]
+
+                end_interface = [interface for interface in path if isinstance(interface, Interface) and
+                                 interface.remote_node_object == lsp_group[0].dest_node_object][0]
+
+            except IndexError:
+                # There is no LSP source/dest match for the Interfaces in path; this may happen
+                # with Demands that take ECMP paths, where one path has LSP shortcuts and other
+                # paths do not have LSP shortcuts
+                return -1  # code for no LSPs on path
 
             slice_to_sub_start_index = path.index(start_interface)
             slice_to_sub_end_index = path.index(end_interface) + 1
@@ -974,12 +1002,12 @@ class FlexModel(_MasterModel):
         # Using the paired interfaces (source_node, dest_node) pairs from G,
         # get the corresponding interface objects from the model to create
         # the Circuit object
-        for interface in graph_interfaces:
+        for interface in iter(graph_interfaces):
             # Get each interface from model for each
             try:
                 int1 = self.get_interface_object_from_nodes(interface[0], interface[1],
                                                             circuit_id=interface[2]['circuit_id'])[0]
-            except (TypeError, IndexError):
+            except (TypeError, IndexError):  # TODO - are the exception catches necessary?
                 msg = ("No matching Interface Object found: source node {}, dest node {} "
                        "circuit_id {} ".format(interface[0], interface[1], interface[2]['circuit_id']))
                 raise ModelException(msg)
@@ -1031,6 +1059,7 @@ class FlexModel(_MasterModel):
         :param local_node_name: Name of local node Interface resides on
         :param remote_node_name: Name of Interface's remote Node
         :param circuit_id: circuit_id of Interface (optional)
+
         :return: list of Interface objects with common local node and remote node
         """
 
@@ -1467,10 +1496,12 @@ class FlexModel(_MasterModel):
         return G
 
     @classmethod
-    def load_model_file(cls, data_file):
+    def load_model_file(cls, data_file):  # TODO - allow commas instead of tabs
         """
-        Opens a network_modeling data file and returns a model containing
-        the info in the data file.  The data file must be of the appropriate
+        Opens a network_modeling data file, returns a model containing
+        the info in the data file, and runs update_simulation().
+
+        The data file must be of the appropriate
         format to produce a valid model.  This cannot be used to open
         multiple models in a single python instance - there may be
         unpredictable results in the info in the models.
@@ -1490,52 +1521,52 @@ class FlexModel(_MasterModel):
         https://github.com/tim-fiola/network_traffic_modeler_py3/blob/master/examples/lsp_model_test_file.csv
 
         The following headers must exist, with the following tab-column
-        names beneath:
+        names beneath::
 
-        INTERFACES_TABLE
-        - node_object_name - name of node	where interface resides
-        - remote_node_object_name	- name of remote node
-        - name - interface name
-        - cost - IGP cost/metric for interface
-        - capacity - capacity
-        - circuit_id - id of the circuit; used to match two Interfaces into Circuits;
-            - each circuit_id can only appear twice in the model
-            - circuit_id can be string or integer
-        - rsvp_enabled (optional) - is interface allowed to carry RSVP LSPs? True|False; default is True
-        - percent_reservable_bandwidth (optional) - percent of capacity allowed to be reserved by RSVP LSPs; this
-        value should be given as a percentage value - ie 80% would be given as 80, NOT .80.  Default is 100
-        - manual_metric (optional) - manually assigned metric for LSP, if not using default metric from topology
-        shortest path
+            INTERFACES_TABLE
+            - node_object_name - name of node	where interface resides
+            - remote_node_object_name	- name of remote node
+            - name - interface name
+            - cost - IGP cost/metric for interface
+            - capacity - capacity
+            - circuit_id - id of the circuit; used to match two Interfaces into Circuits;
+                - each circuit_id can only appear twice in the model
+                - circuit_id can be string or integer
+            - rsvp_enabled (optional) - is interface allowed to carry RSVP LSPs? True|False; default is True
+            - percent_reservable_bandwidth (optional) - percent of capacity allowed to be reserved by RSVP LSPs; this
+            value should be given as a percentage value - ie 80% would be given as 80, NOT .80.  Default is 100
+            - manual_metric (optional) - manually assigned metric for LSP, if not using default metric from topology
+            shortest path
 
-        Note - The existence of Nodes will be inferred from the INTERFACES_TABLE.
-        So a Node created from an Interface does not have to appear in the
-        NODES_TABLE unless you want to add additional attributes for the Node
-        such as latitude/longitude
+            Note - The existence of Nodes will be inferred from the INTERFACES_TABLE.
+            So a Node created from an Interface does not have to appear in the
+            NODES_TABLE unless you want to add additional attributes for the Node
+            such as latitude/longitude
 
-        NODES_TABLE -
-        - name - name of node
-        - lon	- longitude (or y-coordinate)
-        - lat - latitude (or x-coordinate)
+            NODES_TABLE -
+            - name - name of node
+            - lon - longitude (or y-coordinate)
+            - lat - latitude (or x-coordinate)
 
-        Note - The NODES_TABLE is present for 2 reasons:
-        - to add a Node that has no interfaces
-        - and/or to add additional attributes for a Node inferred from
-        the INTERFACES_TABLE
+            Note - The NODES_TABLE is present for 2 reasons:
+            - to add a Node that has no interfaces
+            - and/or to add additional attributes for a Node inferred from
+            the INTERFACES_TABLE
 
-        DEMANDS_TABLE
-        - source - source node name
-        - dest - destination node name
-        - traffic	- amount of traffic on demand
-        - name - name of demand
+            DEMANDS_TABLE
+            - source - source node name
+            - dest - destination node name
+            - traffic	- amount of traffic on demand
+            - name - name of demand
 
-        RSVP_LSP_TABLE (this table is optional)
-        - source - source node name
-        - dest - destination node name
-        - name - name of LSP
-        - configured_setup_bw - if LSP has a fixed, static configured setup bandwidth, place that static value here,
-        if LSP is auto-bandwidth, then leave this blank for the LSP (optional)
-        lsp_metric - manually assigned metric for LSP, if not using default metric from topology
-        shortest path (optional)
+            RSVP_LSP_TABLE (this table is optional)
+            - source - source node name
+            - dest - destination node name
+            - name - name of LSP
+            - configured_setup_bw - if LSP has a fixed, static configured setup bandwidth, place that static value here,
+            if LSP is auto-bandwidth, then leave this blank for the LSP (optional)
+            lsp_metric - manually assigned metric for LSP, if not using default metric from topology
+            shortest path (optional)
 
         Functional model files can be found in this directory in
         https://github.com/tim-fiola/network_traffic_modeler_py3/tree/master/examples
@@ -1687,9 +1718,8 @@ class FlexModel(_MasterModel):
                                                                            lines.index(interface_line)))
                 raise ModelException(msg)
 
-            # TODO - fix this; check for existence of remote node before adding new_interface; get
-            #  the remote node and use that as the new interface remote node
             node_names = [node.name for node in node_set]
+
             if node_name in node_names:
                 node_object = [node for node in node_set if node.name == node_name][0]
             else:
